@@ -256,104 +256,137 @@ void AT_max_electron_ranges_m_R( const int*		number_of_particles,
 );
 
 
-#ifdef HAVE_CERNLIB
+void AT_mean_energy_loss_keV_R( const float*	E_MeV_u,
+		const int*		particle_no,
+		const int*		material_no,
+		const float*	slab_thickness_um,
+		float*			returnValue
+);
+
+
+void AT_xi_keV_R( const float*	E_MeV_u,
+		const int*		particle_no,
+		const int*		material_no,
+		const float*	slab_thickness_um,
+		float*			returnValue
+);
+
+
+void AT_kappa_multi_R( const int*		n,
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const int*		material_no,
+		const float*	slab_thickness_um,
+		float*			kappa
+);
+
+
+void AT_Landau_PDF_R( const int*		n,
+		const float*	lambda_landau,
+		float*			density
+);
+
+
+void AT_Landau_IDF_R( const int*		n,
+		const float*	rnd,
+		float*			lambda_landau
+);
+
+
+void AT_lambda_landau_from_energy_loss_multi_R( const int*		n,
+		const float*	energy_loss_keV,
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const int*		material_no,
+		const float*	slab_thickness_um,
+		float*			lambda_landau
+);
+
+
+void AT_lambda_mean_multi_R( const int*		n,
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const int*		material_no,
+		const float*	slab_thickness_um,
+		float*			lambda_mean
+);
+
+
+void AT_lambda_max_multi_R( const int*		n,
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const int*		material_no,
+		const float*	slab_thickness_um,
+		float*			lambda_max
+);
+
+
+void AT_energy_loss_from_lambda_landau_multi_R( const int*		n,
+		const float*	lambda_landau,
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const int*		material_no,
+		const float*	slab_thickness_um,
+		float*			energy_loss_keV
+);
+
+
 void AT_Vavilov_PDF_R( const int*		n,
-		const float*	lambda_V,
+		const float*	lambda_vavilov,
 		const float*	kappa,
 		const float*	beta,
 		float*			density
 );
-#endif
 
 
-#ifdef HAVE_CERNLIB
-void AT_Landau_PDF_R( const int*		n,
-		const float*	lambda,
+void AT_Vavilov_IDF_R( const int*		n,
+		const float*	rnd,
+		const float*	kappa,
+		const float*	beta,
+		float*			lambda_vavilov
+);
+
+
+void AT_lambda_vavilov_from_energy_loss_multi_R( const int*		n,
+		const float*	energy_loss_keV,
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const int*		material_no,
+		const float*	slab_thickness_um,
+		float*			lambda_vavilov
+);
+
+
+void AT_energy_loss_from_lambda_vavilov_multi_R( const int*		n,
+		const float*	lambda_vavilov,
+		const float*	E_MeV_u,
+		const int*		particle_no,
+		const int*		material_no,
+		const float*	slab_thickness_um,
+		float*			energy_loss_keV
+);
+
+
+void AT_Gauss_PDF_R( const int*		n,
+		const float*	lambda_gauss,
 		float*			density
 );
-#endif
 
 
-void AT_Rutherford_SDCS_R( const float*	E_MeV_u,
-		const int*		particle_no,
-		const int*		material_no,
-		const int*		n,
-		const float*	T_MeV,
-		float*			dsdT_m2_MeV,
-		int*			returnValue
+void AT_Gauss_IDF_R( const int*		n,
+		const float*	rnd,
+		float*			lambda_gauss
 );
 
 
-void AT_Bethe_mean_energy_loss_MeV_R( const float*	E_MeV_u,
-		const int*		particle_no,
-		const int*		material_no,
-		const float*	slab_thickness_um,
-		float*			returnValue
-);
-
-
-void AT_kappa_R( const float*	E_MeV_u,
-		const int*		particle_no,
-		const int*		material_no,
-		const float*	slab_thickness_um,
-		float*			returnValue
-);
-
-
-#ifdef HAVE_CERNLIB
-void AT_lambda_from_energy_loss_R( const int*		n,
-		const float*	energy_loss_keV,
+void AT_energy_loss_from_lambda_gauss_multi_R( const int*		n,
+		const float*	lambda_gauss,
 		const float*	E_MeV_u,
 		const int*		particle_no,
 		const int*		material_no,
 		const float*	slab_thickness_um,
-		float*			lambda_V
+		float*			energy_loss_keV
 );
-#endif
-
-
-#ifdef HAVE_CERNLIB
-void AT_Vavilov_energy_loss_distribution_R( const int*		n,
-		const float*	energy_loss_keV,
-		const float*	E_MeV_u,
-		const int*		particle_no,
-		const int*		material_no,
-		const float*	slab_thickness_um,
-		float*			fDdD
-);
-#endif
-
-
-#ifdef HAVE_CERNLIB
-void AT_energy_loss_distribution_R( const int*		n,
-		const float*	energy_loss_keV,
-		const float*	E_MeV_u,
-		const int*		particle_no,
-		const int*		material_no,
-		const float*	slab_thickness_um,
-		float*			fDdD
-);
-#endif
-
-
-#ifdef HAVE_CERNLIB
-void AT_energy_loss_mode_R( const float*	E_MeV_u,
-		const int*		particle_no,
-		const int*		material_no,
-		const float*	slab_thickness_um,
-		float*			returnValue
-);
-#endif
-
-
-#ifdef HAVE_CERNLIB
-void AT_energy_loss_FWHM_R( const float*	E_MeV_u,
-		const int*		particle_no,
-		const int*		material_no,
-		const float*	slab_thickness_um,
-		float*			returnValue
-);
-#endif
 
 
 void AT_beta_from_E_R( const int*		n,
@@ -410,6 +443,14 @@ void AT_effective_charge_from_E_MeV_u_R( const int*		n,
 );
 
 
+void AT_max_E_transfer_MeV_new_R( const int*		n,
+		const float*	E_MeV_u,
+		const int*		A,
+		float*			max_E_transfer_MeV,
+		int*			returnValue
+);
+
+
 void AT_max_E_transfer_MeV_R( const int*		n,
 		const float*	E_MeV_u,
 		float*			max_E_transfer_MeV,
@@ -539,6 +580,16 @@ void AT_mean_number_of_tracks_contrib_R( const int*		number_of_field_components,
 );
 
 
+void AT_Rutherford_SDCS_R( const float*	E_MeV_u,
+		const int*		particle_no,
+		const int*		material_no,
+		const int*		n,
+		const float*	T_MeV,
+		float*			dsdT_m2_MeV,
+		int*			returnValue
+);
+
+
 void AT_r_RDD_m_R( const int*		n,
 		const float*	D_RDD_Gy,
 		const float*	E_MeV_u,
